@@ -24,7 +24,7 @@ from rdial.events import Events
 
 
 def test_fetch_events_for_task():
-    events = Events.read('tests/data/test')
+    events = Events.read('tests/data/test', write_cache=False)
     expect(len(events.for_task(task='task2'))) == 1
 
 
@@ -35,10 +35,10 @@ def test_fetch_events_for_task():
     ({'year': 2011, 'month': 3, 'day': 31}, 0),
 )
 def test_fetch_events_for_date(date, expected):
-    events = Events.read('tests/data/date_filtering')
+    events = Events.read('tests/data/date_filtering', write_cache=False)
     expect(len(events.for_date(**date))) == expected
 
 
 def test_fetch_events_for_week():
-    events = Events.read('tests/data/date_filtering')
+    events = Events.read('tests/data/date_filtering', write_cache=False)
     expect(len(events.for_week(year=2011, week=9))) == 1
